<?php

namespace App\Controller\OgAgent;

use App\Dto\Input\CommandExecuteInput;
use App\Dto\Input\MultipleClientsInput;
use App\Entity\Client;
use App\Model\ClientStatus;
use App\Model\CommandTypes;
use App\Model\TraceStatus;
use App\Service\Trace\CreateService;
use Doctrine\ORM\EntityManagerInterface;
use Psr\Log\LoggerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Validator\Exception\ValidatorException;
use Symfony\Contracts\HttpClient\Exception\TransportExceptionInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

class RunScriptAction extends AbstractController
{
    public function __construct(
        protected readonly EntityManagerInterface   $entityManager,
        protected readonly HttpClientInterface      $httpClient,
        protected readonly CreateService            $createService,
        protected readonly LoggerInterface          $logger,
    )
    {
    }

    public function __invoke(CommandExecuteInput $input): JsonResponse
    {
        /** @var Client $clientEntity */
        foreach ($input->clients as $clientEntity) {
            $client = $clientEntity->getEntity();

            if (!$client->getIp()) {
                throw new ValidatorException('IP is required');
            }

            $data = [
                'nfn' => 'EjecutarScript',
                'scp' => base64_encode($input->script),
                'ids' => '0'
            ];

            try {
                $response = $this->httpClient->request('POST', 'https://' . $client->getIp() . ':8000/opengnsys/EjecutarScript', [
                    'verify_peer' => false,
                    'verify_host' => false,
                    'headers' => [
                        'Content-Type' => 'application/json',
                    ],
                    'json' => $data,
                ]);
                $this->logger->info('Rebooting client', ['client' => $client->getId()]);

            } catch (TransportExceptionInterface $e) {
                $this->logger->error('Error rebooting client', ['client' => $client->getId(), 'error' => $e->getMessage()]);
                return new JsonResponse(
                    data: ['error' => $e->getMessage()],
                    status: Response::HTTP_INTERNAL_SERVER_ERROR
                );
            }

            $jobId = json_decode($response->getContent(), true)['job_id'];

            $this->entityManager->persist($client);
            $this->entityManager->flush();

            $inputData = [
                'script' => $input->script,
            ];

            $this->createService->__invoke($client, CommandTypes::RUN_SCRIPT, TraceStatus::SUCCESS, $jobId, $inputData);
        }

        return new JsonResponse(data: [], status: Response::HTTP_OK);
    }
}